﻿-- Author      : RisM
-- Create Date : 9/21/2009 3:06:34 AM

local SpeakinSpell = LibStub("AceAddon-3.0"):GetAddon("SpeakinSpell")
local L				= LibStub("AceLocale-3.0"):GetLocale("SpeakinSpell",					false)
local BIGREDBUTTON	= LibStub("AceLocale-3.0"):GetLocale("SpeakinSpell_BIGREDBUTTON",		false)

SpeakinSpell:PrintLoading("gui/generaloptions.lua")


-------------------------------------------------------------------------------
-- GUI LAYOUT - GENERAL SETTINGS
-------------------------------------------------------------------------------


SpeakinSpell.OptionsGUI.args.General = {
	order = 1,
	type = "group",
	name = L["General Settings"],
	desc = L["General Settings TOOLTIP"],
	args = {
		-----------------------
		Caption = {
			order = 1,
			type = "header",
			--name = L["General Settings"],
			name = function()
				SpeakinSpell:SetLastPageViewed( "General", "SpeakinSpell" )
				return L["General Settings"]
			end,
		},
		
		-----------------------
		InfoGroup = {
			order = 2,
			type = "group",
			guiInline = true,
			name = L["Information"],
			args = {
				Version = {
					order = 2,
					type = "description",
					name = L["Version "]..SpeakinSpell.CURRENT_VERSION,
				},
				Memory = {
					order = 3,
					type = "description",
					name = function() return SpeakinSpell:GetAddonMemoryUsedString() end,
				},
--				URLs = {
--					order = 4,
--					type = "description",
--					name = SpeakinSpell.ALL_URLs,
--				},
				Help = {
					order = 5,
					type = "execute",
					name = L["Help"],
					desc = L["Open the User's Manual"],
					func = function() SpeakinSpell:ShowHelp() end,
				},
			},
		},

		-----------------------
		GeneralGroup = {
			order = 3,
			type = "group",
			guiInline = true,
			name = L["General Settings"],
			args = {
				EnableAllMessagesToggle = {
					order = 11,
					type = "toggle",
					width = "full",
					name = L["Enable All Messages"],
					desc = function()
						local ON = (SpeakinSpell.Colors.ON)..L["ON|r"]
						local OFF= (SpeakinSpell.Colors.OFF)..L["OFF|r"]
						local Status = OFF
						if SpeakinSpellSavedData.EnableAllMessages then
							Status = ON
						end
						local tooltip = string.format(L["SpeakinSpell is %s"], Status).."\n\n"
						if SpeakinSpellSavedData.EnableAllMessages then
							tooltip = tooltip..string.format(L["Disable this option to turn SpeakinSpell %s and silence all SpeakinSpell speeches"], OFF)
						else
							tooltip = tooltip..string.format(L["Enable this option to turn SpeakinSpell %s and resume announcing SpeakinSpell Speech Events"], ON)
						end
						return tooltip
					end,
					get = function() return  SpeakinSpell:GeneralOptions_OnEnableAllMessagesToggle("GET",nil) end,
					set = function(_, value) SpeakinSpell:GeneralOptions_OnEnableAllMessagesToggle("SET",value) end,
				},
				EnableMinimapIcon = {
					order = 12,
					type = "toggle",
					name = L["Show Minimap Button"],
					desc = L["Show the SpeakinSpell minimap button"],
					get = function(info) return SpeakinSpellSavedData.ShowMinimapButton end,
					set = function(info, value) SpeakinSpell:MinimapButton_Show(value) end,
				},
				ShowVersionAtLogin = {
					order = 13,
					width = "full",
					type = "toggle",
					name = L["Show: "].. 
						SpeakinSpell.Colors.Channels.SPEAKINSPELL.."SpeakinSpell|r: "..
						string.format(L["Loaded version %s"], SpeakinSpell.CURRENT_VERSION),
					desc = L["Show the version number in chat when loading SpeakinSpell during login"],
					get = function(info) return SpeakinSpellSavedData.ShowVersionAtLogin end,
					set = function(info, value) SpeakinSpellSavedData.ShowVersionAtLogin = value end,
				},
				EditSpeeches = {
					order = 14,
					type = "execute",
					name = L["Edit Speeches"],
					func = function() SpeakinSpell:ShowMessageOptions() end,
				},
			},
		},
		
		-----------------------
		DiagnosticsGroup = {
			order = 20,
			type = "group",
			name = L["Diagnostics"],
			guiInline = true,
			args = {
				ShowSpellEventsToggle = {
					order = 21,
					type = "toggle",
					width = "full",
					name = L["Report detected spell events"],
					desc = L["Report detected spell events TOOLTIP"],
					get = function() return  SpeakinSpell:GeneralOptions_OnShowSpellEventsToggle("GET",nil) end,
					set = function(_, value) SpeakinSpell:GeneralOptions_OnShowSpellEventsToggle("SET",value) end,
				},
				ShowDebugMessagesToggle = {
					order = 22,
					type = "toggle",
					width = "full",
					name = L["Show Debugging Messages (verbose)"],
					desc = L["Show Debugging Messages TOOLTIP"],
					get = function() return  SpeakinSpell:GeneralOptions_OnShowDebugMessagesToggle("GET",nil) end,
					set = function(_, value) SpeakinSpell:GeneralOptions_OnShowDebugMessagesToggle("SET",value) end,
				},
			},
		},
		
		-----------------------
		ScrollGap = {
			order = 100,
			type = "description",
			name = "\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n\n",
		},
		BigRedButton = {
			order = 101,
			type = "execute",
			width = "full",
			name = L["DO NOT PRESS THIS BUTTON"],
			desc = L["Under no circumstances should you ever, EVER push this button.\n\nI'm warning you.\n\nDon't do it.\n\nSeriously, you're already hovering over it for too long, and that's dangerous.\n\nMove your mouse before it's too late!"],
			func = function() SpeakinSpell:GeneralOptions_OnClickBigRedButton() end,
		},
	}, --end args
}

-------------------------------------------------------------------------------
-- OPTIONS GUI FUNCTIONS - GENERAL SETTINGS
-------------------------------------------------------------------------------


function SpeakinSpell:GeneralOptions_OnShowSpellEventsToggle(getset, value)
	if "GET" == getset then
		return SpeakinSpellSavedData.ShowSpellEvents
	else -- "SET"
		SpeakinSpellSavedData.ShowSpellEvents = value
	end
end


function SpeakinSpell:GeneralOptions_OnShowDebugMessagesToggle(getset, value)
	if "GET" == getset then
		return SpeakinSpellSavedData.ShowDebugMessages
	else -- "SET"
		SpeakinSpellSavedData.ShowDebugMessages = value
	end
end


function SpeakinSpell:GeneralOptions_OnEnableAllMessagesToggle(getset, value)
	if "GET" == getset then
		return SpeakinSpellSavedData.EnableAllMessages
	else -- "SET"
		SpeakinSpellSavedData.EnableAllMessages = value
	end
end


function SpeakinSpell:GeneralOptions_OnClickBigRedButton()
	-- check range of BigRedButtonIndex
	if not self.RuntimeData.BigRedButtonIndex then
		self.RuntimeData.BigRedButtonIndex = 1
	end
	if self.RuntimeData.BigRedButtonIndex > #(BIGREDBUTTON.List) then
		self.RuntimeData.BigRedButtonIndex = 1
	end
	
	-- process substitution variables
	local DetectedEventStub = {
		-- event descriptors
		name = "Big Red Button",
		rank = "Silly",
		-- event-specific data for substitutions
		target = self:GetDefaultTarget(false),
		caster = UnitName("player"),
		type = "MACRO",
		linenumber = tostring(self.RuntimeData.BigRedButtonIndex),
	}
	local DetectedEvent = self:CreateDetectedEvent( DetectedEventStub )
	local msg = BIGREDBUTTON.List[ self.RuntimeData.BigRedButtonIndex ]
	
	msg = self:FormatSubs( msg, DetectedEvent )

	-- print the next message in the looping array
	-- NOTE: some empty items are inserted on purpose to make a click non-functional
	--	SayOneLine aborts on empty lines
	self:SayOneLine( msg, "SPEAKINSPELL CHANNEL", nil, DetectedEvent )
	
	-- prepare for the next pass
	self.RuntimeData.BigRedButtonIndex = self.RuntimeData.BigRedButtonIndex + 1
end
